from setuptools import setup, find_packages

setup(
      name = 'evepi',
      version = '0.63',
      keywords = ('evepi', 'adamsolo', 'arduino'),
      url = 'http://evepi.cc',
      description = 'evepi',
      license = 'public domain',
      
      author = 'Zhang Yiwei',
      author_email = 'Karl1991223@126.com',
      
      packages = find_packages(),
      platforms = 'any',
      )
